@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2013 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2014 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -208,17 +208,34 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         });
     }
     
+    @SuppressWarnings("null")
     private void doDownloadAndVerificationAndInstall () {
+        
+        OperationContainer<InstallSupport> installContainer = model.getBaseContainer();
+        final InstallSupport support = installContainer.getSupport();
+        assert support != null : "Operation failed: OperationSupport cannot be null because OperationContainer "
+                + "contains elements: " + installContainer.listAll() + " and invalid elements " + installContainer.listInvalid() + "\ncontainer: " + installContainer;
+        assert installContainer.listInvalid().isEmpty() : support + ".listInvalid().isEmpty() but " + installContainer.listInvalid() + " container: " + installContainer;
+
+        if (support == null) {
+            log.log(Level.WARNING, "Operation failed: OperationSupport was null because OperationContainer "
+                    + "either does not contain any elements: {0} or contains invalid elements {1}",
+                    new Object[]{
+                        model.getBaseContainer().listAll(),
+                        model.getBaseContainer().listInvalid()});
+            return ;
+        }
+        
         Validator v;
         // download
-        if ((v = handleDownload ()) != null) {
+        if ((v = handleDownload(support)) != null) {
             Installer i;
             // verifation
-            if ((i = handleValidation (v)) != null) {
+            if ((i = handleValidation(v, support)) != null) {
                 // installation
                 Restarter r;
-                if ((r = handleInstall (i)) != null) {
-                    presentInstallNeedsRestart (r);
+                if ((r = handleInstall(i, support)) != null) {
+                    presentInstallNeedsRestart(r, support);
                 } else {
                     presentInstallDone ();
                 }
@@ -231,25 +248,12 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
     
     private Validator validator;
     
-    private Validator handleDownload () {
+    private Validator handleDownload(final InstallSupport support) {
         if (canceled) {
             log.fine("Quit handleDownload() because an previous installation was canceled.");
             return null;
         }
         validator = null;
-        OperationContainer<InstallSupport> installContainer = model.getBaseContainer ();
-        final InstallSupport support = installContainer.getSupport ();
-        assert support != null : "OperationSupport cannot be null because OperationContainer " +
-                "contains elements: " + installContainer.listAll () + " and invalid elements " + installContainer.listInvalid () + "\ncontainer: " + installContainer;
-        assert installContainer.listInvalid ().isEmpty () : support + ".listInvalid().isEmpty() but " + installContainer.listInvalid () + " container: " + installContainer;
-        
-        if (support == null) {
-            log.warning("Download failed: OperationSupport was null because OperationContainer "
-                        + "either does not contain any elements: " + model.getBaseContainer().listAll()
-                        + " or contains invalid elements " + model.getBaseContainer().listInvalid());
-            return null;
-        }
-        
         boolean finish = false;
         while (! finish) {
             finish = tryPerformDownload(support);
@@ -421,18 +425,12 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         
     }
     
-    private Installer handleValidation (Validator v) {
+    private Installer handleValidation(Validator v, final InstallSupport support) {
         if (canceled) {
             log.fine("Quit handleValidation() because an previous installation was canceled.");
             return null;
         }
         component.setHeadAndContent (getBundle (HEAD_VERIFY), getBundle (CONTENT_VERIFY));
-        final InstallSupport support = model.getBaseContainer().getSupport();
-        assert support != null : "OperationSupport cannot be null because OperationContainer " +
-                "contains elements: " + model.getBaseContainer ().listAll () + " and invalid elements " + model.getBaseContainer ().listInvalid ();
-        if (support == null) {
-            return null;
-        }
         ProgressHandle handle = ProgressHandleFactory.createHandle (getBundle ("InstallStep_Validate_ValidatingPlugins"));
         JComponent progressComponent = ProgressHandleFactory.createProgressComponent (handle);
         JLabel mainLabel = ProgressHandleFactory.createMainLabelComponent (handle);
@@ -491,7 +489,6 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         try {
             tmpInst = support.doValidate (v, handle);
             if (tmpInst == null) return null;
-            if (tmpInst == null) return null;
         } catch (OperationException ex) {
             log.log (Level.INFO, ex.getMessage (), ex);
             ProblemPanel problem = new ProblemPanel(ex, false);
@@ -567,16 +564,13 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         return inst;
     }
     
-    private Restarter handleInstall (Installer i) {
+    private Restarter handleInstall(Installer i, final InstallSupport support) {
         if (canceled) {
             log.fine("Quit handleInstall() because an previous installation was canceled.");
             return null;
         }
         installException = null;
         component.setHeadAndContent (getBundle (HEAD_INSTALL), getBundle (CONTENT_INSTALL));
-        InstallSupport support = model.getBaseContainer().getSupport();
-        assert support != null : "OperationSupport cannot be null because OperationContainer " +
-                "contains elements: " + model.getBaseContainer ().listAll () + " and invalid elements " + model.getBaseContainer ().listInvalid ();
         model.modifyOptionsForDisabledCancel (wd);
         
         ProgressHandle handle = ProgressHandleFactory.createHandle (getBundle ("InstallStep_Install_InstallingPlugins"));
@@ -655,7 +649,7 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         panel.hideRunInBackground ();
     }
     
-    private void presentInstallNeedsRestart (Restarter r) {
+    private void presentInstallNeedsRestart(Restarter r, final InstallSupport support) {
         if (canceled) {
             log.fine("Quit presentInstallNeedsRestart() because an previous installation was canceled.");
             return ;
@@ -667,7 +661,6 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
         panel.setBody (getBundle ("InstallStep_InstallDone_Text"), model.getAllVisibleUpdateElements ());
         panel.hideRunInBackground ();
         if (runInBackground ()) {
-            InstallSupport support = model.getBaseContainer().getSupport();
             resetLastCheckWhenUpdatingFirstClassModules (model.getAllUpdateElements ());
             support.doRestartLater (restarter);
             try {
@@ -786,7 +779,7 @@ public class InstallStep implements WizardDescriptor.FinishablePanel<WizardDescr
             }
         } else if (restarter != null) {
             if (support == null) {
-                assert model.getBaseContainer().listAll() == null : "OperationSupport is null because OperationContainer " +
+                assert model.getBaseContainer().listAll() == null : "storeSettings failed. OperationSupport is null because OperationContainer " +
                         "contains no elements: " + model.getBaseContainer ().listAll ();
                 return ;
             }
